@@ -68,6 +68,10 @@ global_functions = create_dictionary(data={i["name"]: i for i in
                       "kwargs": {},
                       "special_kwargs": {"IndicatorState": "state",
                                          "LCIAMethods": "lcia_methods"}},
+                     {"name": "UDIF",  # "User Defined Indicator Function"
+                      "full_name": "nexinfosys.command_generators.parser_ast_evaluators.call_udif_function",
+                      "kwargs": {},
+                      "special_kwargs": {"IndicatorState": "state"}},
                      ]
                     })
 
